@@ -13,4 +13,9 @@ CREATE TABLE stocks (
 -- query: insert_into_stocks
 -- params: date: str, trans: str, symbol: str, qty: float, price: float
 
-INSERT INTO stocks VALUES (?,?,?,?,?) ;
+INSERT INTO stocks VALUES (:date, :trans, :symbol, :qty, :price) ;
+
+-- query: select_from_stocks
+-- return: str, str, str, float, float
+
+SELECT * FROM stocks ;
